summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmtextureedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmtextureedit.h')
-rw-r--r--kpovmodeler/pmtextureedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmtextureedit.h b/kpovmodeler/pmtextureedit.h
index e1487794..21852ad9 100644
--- a/kpovmodeler/pmtextureedit.h
+++ b/kpovmodeler/pmtextureedit.h
@@ -35,12 +35,13 @@ class TQCheckBox;
class PMTextureEdit : public PMTextureBaseEdit
{
Q_OBJECT
+ TQ_OBJECT
typedef PMTextureBaseEdit Base;
public:
/**
* Creates a PMTextureEdit with parent and name
*/
- PMTextureEdit( TQWidget* parent, const char* name = 0 );
+ PMTextureEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -35,12 +35,13 @@ class TQCheckBox;
public:
/**
- * Creates a PMTextureEdit with parent and name
+ * Creates a PMTextureEdit with tqparent and name
*/